@@ -1,7 +1,14 @@
 #!/usr/bin/env python2
+# This is a wrapper around pusher.py to provide a command line interface
+
 import os
 import argparse
 
+try:
+    from pypu.version import VERSION
+except ImportError:
+    from version import VERSION
+
 try:
     import pypu.pusher as pusher
 except ImportError:
@@ -10,10 +17,9 @@ except ImportError:
 import logging
 import glob
 
-VERSION='0.1.9'
 
 parser=argparse.ArgumentParser(description='Upload stuff to flickr and wordpress (%s)'%(VERSION),version=VERSION)
-parser.add_argument("action", help="Action flag: st,pull,push,add,rm")
+parser.add_argument("action", help="Action flag: st,push,add,rm")
 parser.add_argument('files', metavar='file', type=str, nargs='+',
     help="Directory or file list to operate on")
 parser.add_argument('-vv','--verbose',help="Verbose debug output",\
